#
# spec file for package plasma-wayland-protocols
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           plasma-wayland-protocols
Version:        1.16.0
Release:        1.1
Summary:        Wayland protocols used by Plasma
License:        BSD-3-Clause AND LGPL-2.1-only AND LGPL-2.1-or-later AND MIT
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/plasma-wayland-protocols/plasma-wayland-protocols-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma-wayland-protocols/plasma-wayland-protocols-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules

%description
This package contains the non-standard Wayland protocol definitions used by
KDE Plasma.

%prep
%autosetup -p1

%build
%cmake_kf6
%kf6_build

%install
%kf6_install
%fdupes %{buildroot}

%files
%license COPYING* LICENSES/*.txt
%{_kf6_sharedir}/plasma-wayland-protocols/
%{_kf6_cmakedir}/PlasmaWaylandProtocols/

%changelog
* Thu Jan  9 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.16.0:
  * external-brightness: Allow the client to specify observed brightness
  * output management: add a failure reason event
  * output device,-management: add a dimming multiplier
  * output device/management: add power/performance vs. color accuracy
    preference
* Sat Dec  7 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.15.0:
  * Add a request to create a virtual output stream with description
  * Add alpine CI
  * Add modifier information to keystate
  * gitignore: use same as KWin
  * Add a destructor to appmenu manager
  * Add protocol tests
  * Add CI for static builds on Linux
* Thu Sep 12 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.14.0:
  * add a protocol for externally controlled display brightness
  * output device: add support for brightness in SDR mode
  * plasma-window: add client geometry + bump to v18
  * Add warnings discouraging third party clients using internal desktop
    environment protocol
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.13.0:
  * new release for Plasma 6.1 beta, 1.13.0
  * plasma-window-management: add a stacking order object
  * output device, output management: add brightness setting
  * outputdevice,outputconfiguration: add a way to use the EDID-provided color profile
  * Enforce passing tests
  * output device, management: change the descriptions for sdr gamut wideness
- Build with KDE Frameworks 6
- Use the same keyring as for Plasma
* Wed Jan 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.12.0:
  * plasma-shell: Mark set_panel_behaviour as deprecated
  * plasma-shell: Drop commented out initial ideas
  * add more HDR settings to the output management protocols
  * docs: Use "provides" instead of "installs"
  * docs: improve readme clarity
  * add an icc profile path to output management protocols
  * outputdevice,outputmanagement: add auto rotate setting
  * fake-input: Add destructor request
  * Make filename match virtual desktop protocol name
  * Bump version number to allow depending on it
  * kde-screen-edge-v1: Add new protocol
  * outputdevice,management: add settings for hdr and color managament
  * Make plane state values in plasma_window_management
* Fri Jan 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Version got changed to 1.10.0 for consistency
* Thu Jan 19 2023 Enrico Belleri <idesmi@protonmail.com>
- Update to 1.10:
  * Add destructor for keystate interface
  * Add a protocol to order the outputs for plasmashell to assign
    desktop environment components to a specific screen
* Wed Sep 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.9.0:
  * Fix plasma-shell version
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.8.0:
  * Fix some reuse warnings
  * Increase org_kde_plasma_window_management version
  * Introduce the kde_lockscreen_overlay_v1 protocol
  * Add FreeBSD Qt6 CI support
  * Make explicit that kde-output-management-v2 is onetime only
  * Fix typos in plasma-virtual-desktop.xml
  * kde-primary-output-v1: Fix DTD violation
* Sat May  7 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.7.0:
  * Add destructor for primary output global
  * Add AppletPanel window type to the org_kde_plasma_surface interface.
  * plasma_surface: Add open_under_cursor request
  * Rename screencast.xml to match the protocol name
  * Add resourceName to plasma windowmanagement
  * screencast: Introduce stream_region
* Thu Jan 13 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.6.0:
  * Add Linux Qt6 CI
  * Use non-deprecated install location variable for CMake config
    files
  * Add support for Primary Outputs
* Sat Nov  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.5.0:
  * screencast: Extend the protocol to allow streaming virtual outputs
* Sun Sep  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.4.0:
  * Add set_frost to contrast protocol
  * outputdevice, outputmanagement: add rgb range setting
  * Add kde_kwin_output_device_mode_v2 to handle output modes
  * org_kde_plasma_window_management: Allow sending windows to an output
  * Decouple activation feedback from window management
  * plasma-window-management: allow to report which apps are starting
* Sun May  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.3.0:
  * Bump to Plasma Wayland Protocols 1.3.0
  * Add VRR to output device and management
  * Add overscan to output protocols
* Mon Apr  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.2.1
- Changes since 1.1.1:
  * Bump version to 1.2.1
  * Bump version to 1.2.0
  * Add the activity management protocol parts
  * Add a TODOKF6 for which protocols should be deprecated by that time
  * fix DTD issue
- Add Vlad's key to plasma-wayland-protocols.keyring
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.1.1. No changelog
* Thu May 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to public 1.0 release
* Fri May  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Initial package
